Learn R Programming

optiSolve (version 1.0.1)

optiSolve-package: tools:::Rd_package_title("optiSolve")

Description

tools:::Rd_package_description("optiSolve")

Arguments

Author

tools:::Rd_package_author("optiSolve")

Maintainer: tools:::Rd_package_maintainer("optiSolve")

Details

The following steps are included in solving a constrained optimization problem (cop):

1) Define the objective with one of the following functions:

linfundefines a linear objective function,
quadfundefines a quadratic objective function,
ratiofundefines a rational objective function.

2) Define the constraints by using the following functions:

lincondefines linear equality and inequality constraints,
quadcondefines quadratic constraints,
ratiocondefines rational constraints,
lbcondefines lower bounds for the variables,
ubcondefines upper bounds for the variables.

3) Put the objective function and the constraints together to define the optimization problem:

copdefines a constrained optimization problem.

4) Solve the optimization problem:

solvecopsolves a constrained optimization problem.

5) Check if the solution fulfils all constraints:

validatechecks if the solution fulfils all constraints, and calculates the values of the constraints.

References

Kraft, D. (1988). A software package for sequential quadratic programming, Technical Report DFVLR-FB 88-28, Institut fuer Dynamik der Flugsysteme, Oberpfaffenhofen, July 1988.

Lange K, Optimization, 2004, Springer.

Madsen K, Nielsen HB, Tingleff O, Optimization With Constraints, 2004, IMM, Technical University of Denmark.